.. qnum::
   :prefix: 3-1-
   :start: 1

What is a Custom Course?
========================

As an instructor, you can make a custom course with a unique name on the Runestone server from an existing Runestone book. Your students will register for your course using the unique name, and then their activities will be tracked. You will then be able to:

* View summaries of student activity for particular questions or pages
* Assemble custom assignments and lab sessions from:

  * existing activities that are built into the book
  * new activities that you author yourself using a markup language (rst)
